Date: 01 4, 2002 12:15:38 PM

# strspellcandidate

## Purpose

Select the best spell-correct candidate for a word, given a list of space-separated candidates (as returned by spellcandidates, for example.)

## Syntax

returnedString = strspellcandidate(wordString, listString)

returnedString - type: str
wordString - type: str
listString - type: str

## Returns

## Remarks

## Example

## See Also

spellcandidates, spellcorrect, spellword, strspellcompare, Spelling Functions